module.exports = _waterfall;

/**
 * @function
 * @param {Function[]} fns
 * @param {Function} callback
 */

function _waterfall (fns, callback) {
  var fnArgs = Array.prototype.slice.apply(arguments);
  if (fnArgs.length === 1) callback = fns.pop();
  if (typeof callback !== 'function') throw new Error('Function expected');
  _next(null);

  function _next (err) {
    var args = Array.prototype.slice.apply(arguments);
    err = args.shift() || null;
    process.nextTick(function () {
      if (err) return callback(err);
      var fn = fns.shift();
      if (typeof fn === 'function') args.push(_next);
      else {
        args.unshift(null);
        fn = callback;
      }
      fn.apply(null, args);
    });
  }
}

